@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 mversion=2.0
 TTSENGINE=cepstral
@@ -8,7 +8,7 @@ echo "--- $TTSENGINE HTTP/TTS $mversion Installation ---"
 # Copy files
 
 perm_dir=775
-perm_files=664
+perm_files=644
 perm_exec=775
 
 src=.
@@ -24,7 +24,7 @@ fi
 echo "Selected www dir : $wwwdirselect"
 
 mkdir -p $dst/$wwwdirselect/tts/$TTSENGINE
-install -m $perm_dir $src/www/* $dst/$wwwdirselect/$TTSENGINE
+install -m $perm_files $src/www/* $dst/$wwwdirselect/tts/$TTSENGINE
 
 echo "--- $TTSENGINE HTTP/TTS $mversion installation has finished ---"
 
